@@ -2,7 +2,7 @@ package Test2::IPC::Driver::Files;
 use strict;
 use warnings;
 
-our $VERSION = '0.000030';
+our $VERSION = '0.000031';
 
 use base 'Test2::IPC::Driver';
 
@@ -128,8 +128,18 @@ sub send {
     my $hfile = $self->hub_file($hid);
     my $dest = $global ? 'GLOBAL' : $hid;
 
-    $self->abort("hub '$hid' is not available! Failed to send event!\n")
-        unless $global || -f $hfile;
+    $self->abort(<<"    EOT") unless $global || -f $hfile;
+hub '$hid' is not available, failed to send event!
+
+There was an attempt to send an event to a hub in a parent process or thread,
+but that hub appears to be gone. This can happen if you fork, or start a new
+thread from inside subtest, and the parent finishes the subtest before the
+child returns.
+
+This can also happen if the parent process is done testing before the child
+finishes. Test2 normally waits automatically in the root process, but will not
+do so if Test::Builder is loaded for legacy reasons.
+    EOT
 
     my $file = $self->event_file($dest, $e);
     my $ready = File::Spec->canonpath("$file.ready");
@@ -310,7 +320,7 @@ This is an experimental release. Using this right now is not recommended.
 
 This is the default, and fallback concurrency model for L<Test2>. This
 sends events between processes and threads using serialized files in a
-temporary directory. This is not particularily fast, but it works everywhere.
+temporary directory. This is not particularly fast, but it works everywhere.
 
 =head1 SYNOPSIS
 
